Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
var ErrBodyReadAfterClose = errors.New("http: invalid Read on closed Body")
ErrBodyReadAfterClose is returned when reading a Request or Response Body after the body has been closed. This typically happens when the body is read after an HTTP Handler calls WriteHeader or Write on its ResponseWriter.
Functions ¶
This section is empty.
Types ¶
type Headers ¶
type Headers struct {
// contains filtered or unexported fields
}
Headers represents HTTP headers key and multiple values.
type Mux ¶
Mux is an HTTP request multiplexer.
type Request ¶
type Request struct {
Method string
URL *url.URL
Proto string
Header Headers
Body string
ContentLength int64
Close bool
Host string
RequestURI string
// contains filtered or unexported fields
}
Request represents an HTTP request.
Click to show internal directories.
Click to hide internal directories.